@@ -150,7 +150,7 @@ def copy_style():
 
         warnings.warn(message, Warning)
 
-        styles["goose-latex.mplstyle"] = {}
+        styles["goose-latex.mplstyle"] = None
 
     # write style definitions
     # -----------------------
@@ -165,7 +165,8 @@ def copy_style():
     # write all styles
     for fname, style in styles.items():
         with open(os.path.join(dirname, fname), "w") as file:
-            yaml.dump(style, file)
+            if style is not None:
+                yaml.dump(style, file)
 
 
 def latex_float(number, fmt="{0:.2g}"):
@@ -194,9 +195,9 @@ def latex_float(number, fmt="{0:.2g}"):
     if "e" in float_str:
         base, exponent = float_str.split("e")
         if base == "1":
-            return fr"10^{{{int(exponent)}}}"
+            return rf"10^{{{int(exponent)}}}"
         else:
-            return fr"{base} \times 10^{{{int(exponent)}}}"
+            return rf"{base} \times 10^{{{int(exponent)}}}"
 
     return float_str
 
@@ -254,7 +255,7 @@ def log_ticks(
 
     exp_lower, exp_upper = lim
     ticks = np.logspace(exp_lower, exp_upper, exp_upper - exp_lower + 1, base=base)
-    labels = [fr"${base}^{{{np.log10(i):.0f}}}$" for i in ticks]
+    labels = [rf"${base}^{{{np.log10(i):.0f}}}$" for i in ticks]
 
     if keep is not None:
         keep = np.array(keep)
@@ -356,7 +357,7 @@ def log_minorticks(
 
     for i in range(exp_lower, exp_upper):
 
-        t = (10 ** i) * np.arange(2, 10, dtype=float)
+        t = (10**i) * np.arange(2, 10, dtype=float)
 
         if i < 0:
             t = np.around(t, -i)
@@ -743,9 +744,10 @@ def plot(x, y, units="absolute", axis=None, **kwargs):
     :options:
 
         **units** ([``'absolute'``] | ``'relative'``)
-            The type of units in which the coordinates are specified. Relative coordinates correspond
-            to a fraction of the relevant axis. If you use relative coordinates, be sure to set the
-            limits and scale before calling this function!
+            The type of units in which the coordinates are specified.
+            Relative coordinates correspond to a fraction of the relevant axis.
+            If you use relative coordinates, be sure to set the limits and scale before calling
+            this function!
 
         ...
             Any ``plt.plot(...)`` option.
@@ -783,9 +785,10 @@ def text(x, y, text, units="absolute", axis=None, **kwargs):
     :options:
 
         **units** ([``'absolute'``] | ``'relative'``)
-            The type of units in which the coordinates are specified. Relative coordinates correspond
-            to a fraction of the relevant axis. If you use relative coordinates, be sure to set the
-            limits and scale before calling this function!
+            The type of units in which the coordinates are specified.
+            Relative coordinates correspond to a fraction of the relevant axis.
+            If you use relative coordinates, be sure to set the limits and scale before calling
+            this function!
 
         ...
             Any ``plt.text(...)`` option.
@@ -820,7 +823,8 @@ def diagonal_powerlaw(
             The power-law exponent.
 
         **ll, lr, tl, tr** (``<list>``)
-            Coordinates of the lower-left, or the lower-right, or the top-left, or the top-right corner.
+            Coordinates of the lower-left, or the lower-right, or the top-left,
+            or the top-right corner.
 
         **width, height** (``<float>``)
             Width or the height.
@@ -912,9 +916,10 @@ def annotate_powerlaw(text, exp, startx, starty, width=None, rx=0.5, ry=0.5, **k
             E.g. ``rx = 0.5, ry = 0.5`` corresponds to the middle of the line.
 
         **units** ([``'relative'``] | ``'absolute'``)
-            The type of units in which the coordinates are specified. Relative coordinates correspond
-            to a fraction of the relevant axis. If you use relative coordinates, be sure to set the
-            limits and scale before calling this function!
+            The type of units in which the coordinates are specified.
+            Relative coordinates correspond to a fraction of the relevant axis.
+            If you use relative coordinates, be sure to set the limits and scale before calling
+            this function!
 
         **axis** ([``plt.gca()``] | ...)
             Specify the axis to which to apply the limits.
@@ -965,11 +970,11 @@ def annotate_powerlaw(text, exp, startx, starty, width=None, rx=0.5, ry=0.5, **k
         [starty, endy] = rel2abs_y([starty, endy], axis)
 
     # determine multiplication constant
-    const = starty / (startx ** exp)
+    const = starty / (startx**exp)
 
     # get end x/y-coordinate
     if endx is not None:
-        endy = const * endx ** exp
+        endy = const * endx**exp
     else:
         endx = (endy / const) ** (1 / exp)
 
@@ -999,9 +1004,10 @@ def plot_powerlaw(exp, startx, starty, width=None, **kwargs):
             Definition of the end coordinate (only on of these options is needed).
 
         **units** ([``'relative'``] | ``'absolute'``)
-            The type of units in which the coordinates are specified. Relative coordinates correspond
-            to a fraction of the relevant axis. If you use relative coordinates, be sure to set the
-            limits and scale before calling this function!
+            The type of units in which the coordinates are specified.
+            Relative coordinates correspond to a fraction of the relevant axis.
+            If you use relative coordinates, be sure to set the limits and scale before calling
+            this function!
 
         **axis** ([``plt.gca()``] | ...)
             Specify the axis to which to apply the limits.
@@ -1057,11 +1063,11 @@ def plot_powerlaw(exp, startx, starty, width=None, **kwargs):
         [starty, endy] = rel2abs_y([starty, endy], axis)
 
     # determine multiplication constant
-    const = starty / (startx ** exp)
+    const = starty / (startx**exp)
 
     # get end x/y-coordinate
     if endx is not None:
-        endy = const * endx ** exp
+        endy = const * endx**exp
     else:
         endx = (endy / const) ** (1 / exp)
 
@@ -1075,8 +1081,8 @@ def plot_powerlaw(exp, startx, starty, width=None, **kwargs):
 
 def grid_powerlaw(exp, insert=0, skip=0, end=-1, step=0, axis=None, **kwargs):
     r"""
-    Draw a power-law grid: a grid that respects a certain power-law exponent. The grid-lines start from
-    the positions of the ticks.
+    Draw a power-law grid: a grid that respects a certain power-law exponent.
+    The grid-lines start from the positions of the ticks.
 
     :arguments:
 
@@ -1260,6 +1266,7 @@ def fit_powerlaw(
     ydata: ArrayLike,
     yerr: ArrayLike = None,
     yerr_mode: str = "differentials",
+    absolute_sigma: bool = True,
     prefactor: float = None,
     exponent: float = None,
     axis: plt.Axes = None,
@@ -1293,10 +1300,16 @@ def fit_powerlaw(
             \delta z &= \left| \frac{\partial z}{\partial y} \right| \delta y \\
             \delta z &= \frac{\delta y}{y}
 
+    .. seealso::
+
+        `scipy.optimize.curve_fit
+        <https://docs.scipy.org/doc/scipy/reference/generated/scipy.optimize.curve_fit.html>`__
+
     :param xdata: Data points along the x-axis.
     :param ydata: Data points along the y-axis.
     :param yerr: Error-bar for ``ydata`` (should be the standard deviation).
     :param yerr_mode: How to treat the error in ``ydata``, see above.
+    :param absolute_sigma: Treat (the effective) ``yerr`` as absolute error.
     :param prefactor: Prefactor :math:`c` (fitted if not specified).
     :param exponent: Exponent :math:`b` (fitted if not specified).
     :param axis: Axis to plot along (not plotted if not specified).
@@ -1307,7 +1320,7 @@ def fit_powerlaw(
         with ``x`` replaced with the specified string.
 
     :param extrapolate:
-        Plot the powerlaw on the full range of ``axis.get_xlim()``.
+        Plot the function on the full range of ``axis.get_xlim()``.
         Instead of ``True``, one can specify plot options for the extrapolated line, e.g.
         ``..., extrapolate=dict(ls="--", c="r"), ...``.
 
@@ -1350,7 +1363,7 @@ def fit_powerlaw(
             sigma = yerr[i][~j] / ydata[i][~j]
             sigma[yerr[i][~j] == 0] = np.finfo(sigma.dtype).eps  # avoid zero division
             fit_opts["sigma"] = sigma
-            fit_opts["absolute_sigma"] = False
+            fit_opts["absolute_sigma"] = absolute_sigma
         else:
             raise OSError("yerr_mode: did you mean 'differentials'?")
 
@@ -1367,7 +1380,7 @@ def fit_powerlaw(
             [
                 r"$({prefactor:.2f} \pm {prefactor_error:.2f})",
                 auto_fmt,
-                r"^{{{exponent:.2f} \pm {prefactor_error:.2f}}}$",
+                r"^{{{exponent:.2f} \pm {exponent_error:.2f}}}$",
             ]
         )
 
@@ -1392,9 +1405,9 @@ def fit_powerlaw(
         xl = np.logspace(np.log10(xl[0]), np.log10(xl[-1]), 1000)
         xu = np.logspace(np.log10(xu[0]), np.log10(xu[-1]), 1000)
 
-    yp = prefactor * xp ** exponent
-    yl = prefactor * xl ** exponent
-    yu = prefactor * xu ** exponent
+    yp = prefactor * xp**exponent
+    yl = prefactor * xl**exponent
+    yu = prefactor * xu**exponent
 
     details["handle"] = axis.plot(xp, yp, **kwargs)
 
@@ -1410,6 +1423,7 @@ def fit_exp(
     ydata: ArrayLike,
     yerr: ArrayLike = None,
     yerr_mode: str = "differentials",
+    absolute_sigma: bool = True,
     prefactor: float = None,
     exponent: float = None,
     axis: plt.Axes = None,
@@ -1439,10 +1453,16 @@ def fit_exp(
             \delta z &= \left| \frac{\partial z}{\partial y} \right| \delta y \\
             \delta z &= \frac{\delta y}{y}
 
+    .. seealso::
+
+        `scipy.optimize.curve_fit
+        <https://docs.scipy.org/doc/scipy/reference/generated/scipy.optimize.curve_fit.html>`__
+
     :param xdata: Data points along the x-axis.
     :param ydata: Data points along the y-axis.
     :param yerr: Error-bar for ``ydata``.
     :param yerr_mode: How to treat the error in ``ydata``, see above.
+    :param absolute_sigma: Treat (the effective) ``yerr`` as absolute error.
     :param prefactor: Prefactor :math:`c` (fitted if not specified).
     :param exponent: Exponent :math:`b` (fitted if not specified).
     :param axis: Axis to plot along (not plotted if not specified).
@@ -1452,7 +1472,7 @@ def fit_exp(
         with ``x`` replaced with the specified string.
 
     :param extrapolate:
-        Plot the powerlaw on the full range of ``axis.get_xlim()``.
+        Plot the function on the full range of ``axis.get_xlim()``.
         Instead of ``True'', one can specify plot options for the extrapolated line, e.g.
         ``..., extrapolate=dict(ls="--", c="r"), ...``.
 
@@ -1495,7 +1515,7 @@ def fit_exp(
             sigma = yerr[i][~j] / ydata[i][~j]
             sigma[yerr[i][~j] == 0] = np.finfo(sigma.dtype).eps  # avoid zero division
             fit_opts["sigma"] = sigma
-            fit_opts["absolute_sigma"] = False
+            fit_opts["absolute_sigma"] = absolute_sigma
         else:
             raise OSError("yerr_mode: did you mean 'differentials'?")
 
@@ -1511,7 +1531,7 @@ def fit_exp(
         fmt = "".join(
             [
                 r"$({prefactor:.2f} \pm {prefactor_error:.2f})",
-                r"\exp( {exponent:.2f} \pm {prefactor_error:.2f}",
+                r"\exp( {exponent:.2f} \pm {exponent_error:.2f}",
                 auto_fmt,
                 ")$",
             ]
@@ -1551,10 +1571,80 @@ def fit_exp(
     return (prefactor, exponent, details)
 
 
+def fit_log(
+    xdata: ArrayLike,
+    ydata: ArrayLike,
+    yerr: ArrayLike = None,
+    **kwargs,
+) -> (float, float, dict):
+    r"""
+    Fit a logarithm :math:`y = a + b \ln x`.
+    See documentation of :py:func:`fit_linear`.
+    """
+
+    xdata = np.array(xdata)
+    ydata = np.array(ydata)
+
+    i = xdata > 0
+    logx = np.log(xdata[i])
+    y = ydata[i]
+
+    j = np.isnan(logx)
+    logx = logx[~j]
+    y = y[~j]
+
+    axis = kwargs.pop("axis", None)
+    offset, slope, details = fit_linear(logx, y, **kwargs)
+    auto_fmt = kwargs.pop("auto_fmt", None)
+    extrapolate = kwargs.pop("extrapolate", False)
+    kwargs.pop("sigma", None)
+    kwargs.pop("absolute_sigma", None)
+    kwargs.pop("offset", None)
+    kwargs.pop("slope", None)
+    kwargs.pop("fmt", None)
+
+    if auto_fmt:
+        n = 1 + len(auto_fmt)
+        details["label"] = details["label"][:-n] + auto_fmt + r"$"
+
+    if axis is None:
+        return (offset, slope, details)
+
+    if "label" in details:
+        kwargs["label"] = details["label"]
+
+    xp = np.array([np.min(np.exp(logx)), np.max(np.exp(logx))])
+    xl = np.array([axis.get_xlim()[0], xp[0]])
+    xu = np.array([xp[1], axis.get_xlim()[1]])
+
+    if isinstance(extrapolate, bool) and extrapolate:
+        xp = np.array(axis.get_xlim())
+        if xp[0] == 0:
+            xp[0] = np.finfo(np.float64).eps
+
+    if axis.get_xscale() != "log":
+        xp = np.logspace(np.log10(xp[0]), np.log10(xp[-1]), 1000)
+        xl = np.logspace(np.log10(xl[0]), np.log10(xl[-1]), 1000)
+        xu = np.logspace(np.log10(xu[0]), np.log10(xu[-1]), 1000)
+
+    yp = offset + slope * np.log(xp)
+    yl = offset + slope * np.log(xl)
+    yu = offset + slope * np.log(xu)
+
+    details["handle"] = axis.plot(xp, yp, **kwargs)
+
+    if isinstance(extrapolate, dict):
+        details["handle_lower"] = axis.plot(xl, yl, **extrapolate)
+        details["handle_upper"] = axis.plot(xu, yu, **extrapolate)
+
+    return (offset, slope, details)
+
+
 def fit_linear(
     xdata: ArrayLike,
     ydata: ArrayLike,
     yerr: ArrayLike = None,
+    absolute_sigma: bool = True,
     offset: float = None,
     slope: float = None,
     axis: plt.Axes = None,
@@ -1566,9 +1656,15 @@ def fit_linear(
     r"""
     Fit a linear function :math:`y = a + b x`.
 
+    .. seealso::
+
+        `scipy.optimize.curve_fit
+        <https://docs.scipy.org/doc/scipy/reference/generated/scipy.optimize.curve_fit.html>`__
+
     :param xdata: Data points along the x-axis.
     :param ydata: Data points along the y-axis.
     :param yerr: Error-bar for ``ydata``.
+    :param absolute_sigma: Treat (the effective) ``yerr`` as absolute error.
     :param offset: Offset :math:`a` (fitted if not specified).
     :param slope: Slope :math:`b` (fitted if not specified).
     :param axis: Axis to plot along (not plotted if not specified).
@@ -1579,7 +1675,7 @@ def fit_linear(
         with ``x`` replaced with the specified string.
 
     :param extrapolate:
-        Plot the powerlaw on the full range of ``axis.get_xlim()``.
+        Plot the function on the full range of ``axis.get_xlim()``.
         Instead of ``True``, one can specify plot options for the extrapolated line, e.g.
         ``..., extrapolate=dict(ls="--", c="r"), ...``.
 
@@ -1612,7 +1708,7 @@ def fit_linear(
         sigma = np.array(yerr).astype(float)
         sigma[yerr == 0] = np.finfo(sigma.dtype).eps  # avoid zero division
         fit_opts["sigma"] = sigma
-        fit_opts["absolute_sigma"] = False
+        fit_opts["absolute_sigma"] = absolute_sigma
 
     if offset is None and slope is None:
 
@@ -1806,6 +1902,8 @@ def histogram_bin_edges_mincount(data, min_count, bins):
             k = idx + 2
             bins = np.hstack((bins[:j], bins[k:]))
 
+    return bins
+
 
 def histogram_bin_edges_integer(bin_edges):
     r"""
@@ -1993,7 +2091,8 @@ def histogram(data, return_edges=True, **kwargs):
 def histogram_cumulative(data, **kwargs):
     r"""
     Compute cumulative histogram.
-    See `numpy.histrogram <https://docs.scipy.org/doc/numpy/reference/generated/numpy.histogram.html>`__
+    See `numpy.histrogram
+    <https://docs.scipy.org/doc/numpy/reference/generated/numpy.histogram.html>`__
 
     :extra options:
 
@@ -2130,6 +2229,9 @@ def bin(x: ArrayLike, y: ArrayLike, bin_edges: ArrayLike | int, use_median: bool
         yerr: std(y) for each bin.
     """
 
+    x = np.array(x)
+    y = np.array(y)
+
     j = np.digitize(x, bin_edges) - 1
     n = bin_edges.size - 1
 
@@ -2138,6 +2240,7 @@ def bin(x: ArrayLike, y: ArrayLike, bin_edges: ArrayLike | int, use_median: bool
         "y": np.NaN * np.ones(n, dtype=float),
         "xerr": np.NaN * np.ones(n, dtype=float),
         "yerr": np.NaN * np.ones(n, dtype=float),
+        "n": np.zeros(n, dtype=int),
     }
 
     assert np.max(j) < ret["x"].size
@@ -2148,6 +2251,7 @@ def bin(x: ArrayLike, y: ArrayLike, bin_edges: ArrayLike | int, use_median: bool
             continue
 
         sel = j == i
+        ret["n"][i] = np.sum(sel)
 
         if not use_median:
             ret["x"][i] = np.mean(x[sel])
@@ -2176,8 +2280,16 @@ def patch(*args, **kwargs):
 
             fig,ax = plt.subplots()
 
-            p = gplt.patch(coor=coor+disp,conn=conn,axis=ax,cindex=stress,cmap='YlOrRd',edgecolor=None)
-            _ = gplt.patch(coor=coor     ,conn=conn,axis=ax)
+            p = gplt.patch(
+                coor=coor + disp,
+                conn=conn,
+                axis=ax,
+                cindex=stress,
+                cmap='YlOrRd',
+                edgecolor=None
+            )
+
+            _ = gplt.patch(coor=coor, conn=conn, axis=ax)
 
             cbar = fig.colorbar(p,axis=ax,aspect=10)
 
@@ -2194,7 +2306,8 @@ def patch(*args, **kwargs):
             Matrix with on each row the coordinates (positions) of each node.
 
         **conn** (``<numpy.ndarray>`` | ``<list>`` (nested))
-            Matrix with on each row the number numbers (rows in ``coor``) which form an element (patch).
+            Matrix with on each row the number numbers (rows in ``coor``)
+            which form an element (patch).
 
     :options:
 
@@ -2205,8 +2318,8 @@ def patch(*args, **kwargs):
             Specify an axis to include to plot in. By default the current axis is used.
 
         **autoscale** ([``True``] | ``False``)
-            Automatically update the limits of the plot (currently automatic limits of Collections are
-            not supported by matplotlib).
+            Automatically update the limits of the plot
+            (currently automatic limits of Collections are not supported by matplotlib).
 
     :recommended options:
 
